# snitch-protos

Protobuf definitions used for communication between [snitch-server](https://github.com/streamdal/snitch-server) 
and [snitch-client-python](https://github.com/streamdal/snitch-server-python)
